==> dhcp-agent-0.40.tar.gz: dhcp-agent-0.40/src/dhcp-server-conf.h <==
/* $Header: /cvsroot/dhcp-agent/dhcp-agent/src/dhcp-server-conf.h,v 1.2 2003/07/06 05:37:44 actmodern Exp $
 * 
 * Copyright 2002 Thamer Alharbash <tmh@whitefang.com>
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the
 * distribution.
 * 3. The names of the authors may not be used to endorse or promote
 * products derived from this software without specific prior
 * written permission.
 * 
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

#ifndef DHCP_SERVER_CONF_H
#define DHCP_SERVER_CONF_H

/* data structures. */

typedef struct {

    list_t *lease_defs; /* list of lease definitions. */

    const char *interface;    /* interface name: read only.  */
    char *conf_file;          /* path to configuration file. */

    uint16_t default_rebind_percent;   /* percent of expiry to assign as rebind time. */
    uint16_t default_renew_percent;    /* percent of expiry to assign as renew time. */

} server_conf_t;

typedef int (*directive_handler_t)(server_conf_t *server_conf, directive_t *directive_data, void *group_data);

/* constants. */

enum var_symbols { SERVER_VAR_RENEW_PERCENT = 0, SERVER_VAR_REBIND_PERCENT };
enum directive_types { DIRECTIVE_SET = 0, DIRECTIVE_RANGE_LEASE };

/* prototypes. */

extern server_conf_t *server_conf_create(const char *interface);
extern void server_conf_destroy(server_conf_t *sc);

#endif /* DHCP_SERVER_CONF_H */

==> dhcp-agent-0.41.tar.gz: dhcp-agent-0.41/src/dhcp-server-conf.h <==
/* $Header: /cvsroot/dhcp-agent/dhcp-agent/src/dhcp-server-conf.h,v 1.7 2003/07/15 10:56:34 actmodern Exp $
 * 
 * Copyright 2002 Thamer Alharbash <tmh@whitefang.com>
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the
 * distribution.
 * 3. The names of the authors may not be used to endorse or promote
 * products derived from this software without specific prior
 * written permission.
 * 
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

#ifndef DHCP_SERVER_CONF_H
#define DHCP_SERVER_CONF_H

/* data structures. */

typedef struct {

    list_t *lease_defs; /* list of lease definitions. */

    const char *interface;    /* interface name: read only.  */
    char *conf_file;          /* path to configuration file. */

    uint16_t default_rebind_percent;   /* percent of expiry to assign as rebind time. */
    uint16_t default_renew_percent;    /* percent of expiry to assign as renew time. */
    uint16_t poll_timeout;             /* poll timeout -- used in server event processing. */

} server_conf_t;

typedef int (*directive_handler_t)(server_conf_t *server_conf, directive_t *directive_data, int group_type, void *group_data);

/* constants. */

enum var_symbols { SERVER_VAR_RENEW_PERCENT = 0, SERVER_VAR_REBIND_PERCENT, SERVER_VAR_POLL_TIMEOUT };
enum directive_types { DIRECTIVE_SET = 0, DIRECTIVE_RANGE_LEASE, DIRECTIVE_HOSTNAME_LEASE, DIRECTIVE_MAC_LEASE, DIRECTIVE_OPTION };
enum group_types { GROUP_NULL = 0, GROUP_LEASE_DEF };

/* prototypes. */

extern server_conf_t *server_conf_create(const char *interface);
extern void server_conf_destroy(server_conf_t *sc);

extern uint16_t server_conf_get_poll_timeout(server_conf_t *sc);

#endif /* DHCP_SERVER_CONF_H */
